@@ -80,18 +80,19 @@ class Mcdbot(discord.Client):
                 try:
                     await self.redis.start()
                 except ConnectionError as ce:
-                    logger.error(f"Connection error => {ce}")
+                    logger.error(f"Redis connection error => {ce}")
 
                 try:
                     await self.rcon.start()
                 except ConnectionError as ce:
-                    logger.error(f"Connection error => {ce}")
+                    logger.error(f"RCON connection error => {ce}")
 
                 try:
                     await self.mojang_api.start()
                 except ConnectionError as ce:
-                    logger.error(f"Connection error => {ce}")
+                    logger.error(f"Mojang API connection error => {ce}")
 
+                logger.debug(f"Starting with token: {token}")
                 await self.start(token)
             except Exception as e:
                 logger.exception("Unhandled runner exception", e)
