@@ -29,8 +29,9 @@ class Rcon(object):
                 self.started = True
 
     async def stop(self):
-        self.started = False
-        self._rcon.close()
+        if self.started:
+            self.started = False
+            self._rcon.close()
 
     async def authme_register(self, player, password):
         await self.start()
